# HeliosMedPrep

HeliosMedPrep is a library designed to facilitate the preprocessing of data from the MIMIC-III database. It is part of the Helios ecosystem, developed to improve efficiency and usability in medical research using MIMIC data. HeliosMedPrep includes various functions to prepare hospitalization data for machine learning models.